"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var url_1 = require("url");
exports.NOTION_BASE_URL = "https://www.notion.so";
exports.isPageId = function (text) {
    var re = new RegExp('^[a-z0-9]{8}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{12}$');
    return text.length === 36 && re.test(text);
};
exports.getBlockHashId = function (blockId) {
    return blockId.split('-').join('');
};
exports.getFullBlockId = function (blockId) {
    if (blockId.match("^[a-zA-Z0-9]+$")) {
        return blockId.substr(0, 8) + "-"
            + blockId.substr(8, 4) + "-"
            + blockId.substr(12, 4) + "-"
            + blockId.substr(16, 4) + "-"
            + blockId.substr(20, 32);
    }
    else {
        return blockId;
    }
};
exports.getBrowseableUrl = function (blockID) {
    return exports.NOTION_BASE_URL + "/" + blockID.split('-').join('');
};
exports.getUrlPageId = function (url) {
    var pUrl = url_1.parse(url);
    var pathList = pUrl.pathname.split('/');
    var pagId = pathList[pathList.length - 1];
    return pagId;
};
exports.parseImageUrl = function (url, width) {
    var rUrl;
    if (url.startsWith("https://s3")) {
        var parsedOriginUrl = url.split("?")[0];
        rUrl = exports.NOTION_BASE_URL + "/image/" + encodeURIComponent(parsedOriginUrl).replace("s3.us-west", "s3-us-west");
    }
    else if (url.startsWith("/image")) {
        rUrl = "" + exports.NOTION_BASE_URL + url;
    }
    else {
        rUrl = url;
    }
    if (width) {
        return rUrl + "?width=" + width;
    }
    else {
        return rUrl;
    }
};
exports.formatDate = function (date) {
    return date.getFullYear() + "-" + (date.getMonth() + 1 + "").padStart(2, "0") + "-" + (date.getDate() + "").padStart(2, "0");
};
exports.formatTime = function (date) {
    return (date.getHours() + "").padStart(2, "0") + ":" + (date.getMinutes() + "").padStart(2, "0");
};
exports.fixTimeZone = function (dateAsString, timeZone) {
    var shortTz = new Date().
        toLocaleString("en", { timeZoneName: "short", timeZone: timeZone }).
        split(' ').
        pop();
    return new Date(dateAsString + " " + shortTz);
};
exports.unFixTimeZone = function (date, timeZone) {
    var adjustedTime = date.toLocaleString("en-US", { timeZone: timeZone });
    return new Date(adjustedTime);
};
